==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/link/lang/gl.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'gl', {
	acccessKey: 'Chave de acceso',
	advanced: 'Avanzado',
	advisoryContentType: 'Tipo de contido informativo',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: 'Ancoraxe',
		menu: 'Editar a ancoraxe',
		title: 'Propiedades da ancoraxe',
		name: 'Nome da ancoraxe',
		errorName: 'Escriba o nome da ancoraxe',
		remove: 'Retirar a ancoraxe'
	},
	anchorId: 'Polo ID do elemento',
	anchorName: 'Polo nome da ancoraxe',
	charset: 'Codificación do recurso ligado',
	cssClasses: 'Clases da folla de estilos',
	download: 'Forzar a descarga',
	displayText: 'Amosar o texto',
	emailAddress: 'Enderezo de correo',
	emailBody: 'Corpo da mensaxe',
	emailSubject: 'Asunto da mensaxe',
	id: 'ID',
	info: 'Información da ligazón',
	langCode: 'Código do idioma',
	langDir: 'Dirección de escritura do idioma',
	langDirLTR: 'Esquerda a dereita (LTR)',
	langDirRTL: 'Dereita a esquerda (RTL)',
	menu: 'Editar a ligazón',
	name: 'Nome',
	noAnchors: '(Non hai ancoraxes dispoñíbeis no documento)',
	noEmail: 'Escriba o enderezo de correo',
	noUrl: 'Escriba a ligazón URL',
	noTel: 'Escriba o número de teléfono',
	other: '<other>',
	phoneNumber: 'Número de teléfono',
	popupDependent: 'Dependente (Netscape)',
	popupFeatures: 'Características da xanela emerxente',
	popupFullScreen: 'Pantalla completa (IE)',
	popupLeft: 'Posición esquerda',
	popupLocationBar: 'Barra de localización',
	popupMenuBar: 'Barra do menú',
	popupResizable: 'Redimensionábel',
	popupScrollBars: 'Barras de desprazamento',
	popupStatusBar: 'Barra de estado',
	popupToolbar: 'Barra de ferramentas',
	popupTop: 'Posición superior',
	rel: 'Relación',
	selectAnchor: 'Seleccionar unha ancoraxe',
	styles: 'Estilo',
	tabIndex: 'Índice de tabulación',
	target: 'Destino',
	targetFrame: '<marco>',
	targetFrameName: 'Nome do marco de destino',
	targetPopup: '<xanela emerxente>',
	targetPopupName: 'Nome da xanela emerxente',
	title: 'Ligazón',
	toAnchor: 'Ligar coa ancoraxe no testo',
	toEmail: 'Correo',
	toUrl: 'URL',
	toPhone: 'Teléfono',
	toolbar: 'Ligazón',
	type: 'Tipo de ligazón',
	unlink: 'Eliminar a ligazón',
	upload: 'Enviar'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/gl.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'gl', {
	acccessKey: 'Chave de acceso',
	advanced: 'Avanzado',
	advisoryContentType: 'Tipo de contido informativo',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: 'Ancoraxe',
		menu: 'Editar a ancoraxe',
		title: 'Propiedades da ancoraxe',
		name: 'Nome da ancoraxe',
		errorName: 'Escriba o nome da ancoraxe',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Retirar a ancoraxe'
	},
	anchorId: 'Polo ID do elemento',
	anchorName: 'Polo nome da ancoraxe',
	charset: 'Codificación do recurso ligado',
	cssClasses: 'Clases da folla de estilos',
	download: 'Forzar a descarga',
	displayText: 'Amosar o texto',
	emailAddress: 'Enderezo de correo',
	emailBody: 'Corpo da mensaxe',
	emailSubject: 'Asunto da mensaxe',
	id: 'ID',
	info: 'Información da ligazón',
	langCode: 'Código do idioma',
	langDir: 'Dirección de escritura do idioma',
	langDirLTR: 'Esquerda a dereita (LTR)',
	langDirRTL: 'Dereita a esquerda (RTL)',
	menu: 'Editar a ligazón',
	name: 'Nome',
	noAnchors: '(Non hai ancoraxes dispoñíbeis no documento)',
	noEmail: 'Escriba o enderezo de correo',
	noUrl: 'Escriba a ligazón URL',
	noTel: 'Escriba o número de teléfono',
	other: '<other>',
	phoneNumber: 'Número de teléfono',
	popupDependent: 'Dependente (Netscape)',
	popupFeatures: 'Características da xanela emerxente',
	popupFullScreen: 'Pantalla completa (IE)',
	popupLeft: 'Posición esquerda',
	popupLocationBar: 'Barra de localización',
	popupMenuBar: 'Barra do menú',
	popupResizable: 'Redimensionábel',
	popupScrollBars: 'Barras de desprazamento',
	popupStatusBar: 'Barra de estado',
	popupToolbar: 'Barra de ferramentas',
	popupTop: 'Posición superior',
	rel: 'Relación',
	selectAnchor: 'Seleccionar unha ancoraxe',
	styles: 'Estilo',
	tabIndex: 'Índice de tabulación',
	target: 'Destino',
	targetFrame: '<marco>',
	targetFrameName: 'Nome do marco de destino',
	targetPopup: '<xanela emerxente>',
	targetPopupName: 'Nome da xanela emerxente',
	title: 'Ligazón',
	toAnchor: 'Ligar coa ancoraxe no testo',
	toEmail: 'Correo',
	toUrl: 'URL',
	toPhone: 'Teléfono',
	toolbar: 'Ligazón',
	type: 'Tipo de ligazón',
	unlink: 'Eliminar a ligazón',
	upload: 'Enviar'
} );
